/* file: data/static/awg/cable_finder.css */
.cable-form {
    margin-bottom: 1em;
}
.form-table {
    border-collapse: collapse;
}
.form-table td {
    padding: 4px 8px;
    vertical-align: top;
}
.form-table label {
    display: block;
    font-weight: 600;
    font-size: 1.1em;
    margin-bottom: 4px;
}
.form-table.two-col td {
    width: 50%;
    padding-bottom: 16px;
}
.cable-form input,
.cable-form select {
    width: 100%;
    padding: 4px 6px;
    font-size: 1em;
    box-sizing: border-box;
}
.cable-form button.submit {
    width: 100%;
    padding: 4px 6px;
    font-size: 1em;
    box-sizing: border-box;
}
.warning {
    background: #fee;
    color: #b00;
    padding: 0.6em 0.8em;
    border-radius: 4px;
    margin-top: 0.6em;
}

.sponsor-logo {
    float: right;
    margin-left: 1em;
    max-width: 140px;
}

.calc-result {
    margin-top: 1em;
}

.result-list {
    margin-top: 0;
}

@media (min-width: 768px) {
    .result-list {
        font-size: 1.5em;
    }
}

