/* Tabs container */
.gway-net-dashboard .monitor-tabs {
    display: flex;
    border-bottom: 1.5px solid #bbb;
    margin-bottom: 8px;
    gap: 1px;
}

.gway-net-dashboard .monitor-tab {
    padding: 8px 18px 7px 18px;
    cursor: pointer;
    background: #eee;
    border: none;
    border-radius: 6px 6px 0 0;
    margin-right: 3px;
    font-weight: bold;
    color: #555;
    transition: background 0.18s;
}

.gway-net-dashboard .monitor-tab.active,
.gway-net-dashboard .monitor-tab:hover {
    background: #fff;
    color: #000;
    border-bottom: 1.5px solid #fff;
}

.gway-net-dashboard .monitor-block {
    display: none;
    border: 1.5px solid #ccc;
    border-radius: 0 0 12px 12px;
    padding: 16px 18px 14px 18px;
    background: #fff;
    margin-bottom: 20px;
}

.gway-net-dashboard .monitor-block.active {
    display: block;
}

.gway-net-dashboard .monitor-meta {
    border-top: 1px dashed #ccc;
    margin-top: 12px;
    padding-top: 4px;
    font-size: 88%;
    color: #888;
}

.gway-net-dashboard .monitor-frag {
    margin-top: 0.5em;
    margin-bottom: 0.8em;
}

.gway-net-dashboard .error,
.gway-net-dashboard .no-render {
    color: #c00;
    background: #fff0f0;
    padding: 0.5em 0.8em;
    border-radius: 4px;
    margin-bottom: 5px;
}
