/* xp-summer.css — Windows XP Summer Edition for GWAY
   Layer atop base.css. Designed for max nostalgia + summer joy!
*/

:root {
    --bg: linear-gradient(180deg, #cceaff 0%, #f7ffe3 100%);
    --bg-alt: #e6f7ff;
    --card-bg: #f4ffe6;
    --fg: #194783;
    --accent: #0096fa;
    --accent-alt: #33c648;
    --muted: #6292b1;
    --summer-yellow: #ffe34f;
    --summer-green: #6fcf4a;
    --summer-blue: #7ec3ff;
    --summer-shadow: #b3f1f6;
    --xp-window: #e3ecfa;
    --xp-title: #1452b5;
}

body, .page-wrap {
    background: var(--bg) fixed !important;
}

aside {
    background: linear-gradient(150deg, #e8f7ff 60%, #b5f2ea 100%);
    border-right: 2px solid #aadcf5;
    font-family: 'Trebuchet MS', 'Segoe UI', Arial, sans-serif;
    color: var(--fg);
    box-shadow: 2px 0 15px #a7e8f333;
}

aside ul li a {
    color: #1452b5;
    font-family: 'Trebuchet MS', 'Segoe UI', Arial, sans-serif;
    border-radius: 8px;
    font-size: 0.93em;
    padding-left: 1em;
    transition: background 0.18s, color 0.18s;
}
aside ul li a.active,
aside ul li a:hover {
    background: linear-gradient(90deg, #f2fcff 20%, #a7f6d3 80%);
    color: #15700b;
    font-weight: bold;
}

aside ul.sub-links {
    list-style: none;
    padding-left: 1em;
    margin: 0.2em 0 0.4em;
    font-size: 0.85em;
}

aside ul.sub-links li a {
    text-transform: none;
    padding: 0.2em 0 0.2em 1em;
}

main {
    background: linear-gradient(180deg, #f9ffff 90%, #eafff6 100%);
    box-shadow: 0 0 16px #b3f1f655;
    border-radius: 16px 16px 0 0;
    border-top: 4px solid #60b3ff;
}

h1, h2, h3, h4 {
    font-family: 'Trebuchet MS', 'Segoe UI', Arial, sans-serif;
    color: #0a3d8f;
    text-shadow: 1px 2px 0 #fff8, 0 0 3px #b3e1ff55;
    letter-spacing: 0.01em;
}
h1 {
    color: var(--xp-title);
    font-size: 2.4em;
    margin-top: 1.1em;
}
h2 {
    color: #1f7bdc;
    border-bottom: 2px solid #ffe34f55;
    padding-bottom: 0.18em;
}

button,
input[type="submit"],
input[type="button"] {
    background: linear-gradient(180deg, #fffcb2 0%, #7edcfe 80%);
    color: #166d1a;
    border: 2px solid #60b3ff;
    box-shadow: 1px 2px 0 #f5f9ff, 0 4px 10px #b3f1f655;
    font-family: 'Trebuchet MS', 'Segoe UI', Arial, sans-serif;
    border-radius: 8px;
    font-weight: bold;
    text-shadow: 1px 1px #fff8;
    transition: background 0.2s, box-shadow 0.2s, border 0.15s;
}
button:hover,
input[type="submit"]:hover {
    background: linear-gradient(180deg, #d0ffe2 0%, #85e2ff 100%);
    color: #106621;
    border-color: #33c648;
    box-shadow: 0 0 10px #7ec3ff44;
}
button:active,
input[type="submit"]:active {
    background: linear-gradient(180deg, #fff8a7 0%, #c6f7ff 100%);
    color: #0d4c09;
    box-shadow: 0 1px 2px #96fbc1;
}

input,
textarea,
select {
    background: #f7fbff;
    border: 1.5px solid #88c3ee;
    border-radius: 7px;
    box-shadow: 0 1px 4px #d0eeff44;
    font-family: 'Trebuchet MS', 'Segoe UI', Arial, sans-serif;
    width: 100%;
    box-sizing: border-box;
}
input:focus,
textarea:focus,
select:focus {
    border-color: #5ad5fe;
    background: #e4fff5;
    outline: 2px solid #b9e8f9;
}

pre, code, pre code {
    background: #e7f5ff !important;
    color: #194783 !important;
    font-family: 'Consolas', 'Fira Mono', 'Menlo', monospace;
    border-radius: 9px;
    box-shadow: 0 2px 8px #a3e8ff22;
}

.current, .active {
    color: #fff !important;
    background: linear-gradient(90deg, #62a7ff 60%, #90e8c6 100%);
    box-shadow: 0 0 8px #70e1c1cc;
    border-radius: 8px;
    font-weight: bold;
}

footer {
    background: linear-gradient(90deg, #f2ffcf 50%, #b3f1f6 100%);
    color: #339c2e;
    border-top: 2px solid #b7e7f8;
    font-family: 'Trebuchet MS', 'Segoe UI', Arial, sans-serif;
}

.help-entry {
    background: #f3fff7;
    border: 1.5px solid #b0e2f3;
    box-shadow: 0 2px 12px #bee1ff44;
}
.help-entry .doc {
    background: #e2f4d6;
    color: #247f25;
    border-left: 3px solid #33c648;
}
.help-entry pre, .help-entry pre code.python {
    background: #e7f8ff;
    color: #1c396a;
    box-shadow: 0 1px 3px #b3f1f633;
}
.help-entry a {
    color: #0b71da;
}
.help-entry a:hover {
    background: #fff0ab;
    color: #15700b;
}

/* Windows XP start button homage */
.xp-start {
    display: inline-block;
    background: linear-gradient(180deg, #60d548 10%, #13a90a 90%);
    color: #fff;
    border: 2px solid #2f962d;
    border-radius: 13px 13px 13px 13px / 22px 22px 20px 20px;
    font-family: 'Trebuchet MS', Arial, sans-serif;
    font-size: 1.09em;
    font-weight: bold;
    padding: 0.5em 1.6em 0.5em 2.4em;
    box-shadow: 0 2px 8px #54c86b55;
    margin: 1em 0.5em 1em 0;
    position: relative;
}
.xp-start::before {
    content: "";
    display: inline-block;
    position: absolute;
    left: 0.65em; top: 0.47em;
    width: 1.2em; height: 1.2em;
    background: url('data:image/svg+xml;utf8,<svg width="20" height="20" viewBox="0 0 20 20" fill="limegreen" xmlns="http://www.w3.org/2000/svg"><circle cx="10" cy="10" r="8" stroke="white" stroke-width="3" fill="limegreen"/><text x="5.6" y="15.6" font-size="10" fill="white" font-family="Arial">X</text></svg>') no-repeat center center / contain;
}

hr {
    border: none;
    border-top: 2px solid #60b3ff77;
    margin: 2.2em 0 1.2em 0;
    opacity: 0.7;
}

/* Responsive tweaks for summer theme */
@media (max-width: 650px) {
    main {
        border-radius: 0;
        box-shadow: none;
        padding: 0.5em;
    }
    aside {
        padding: 1em 0.5em;
    }
}

/* XP "Bliss" grass footer bar */
footer::after {
    content: "";
    display: block;
    width: 100%;
    height: 24px;
    background: linear-gradient(180deg, #83e35a 40%, #a6fc7a 90%);
    border-radius: 0 0 11px 11px;
    margin-top: 0.5em;
    box-shadow: 0 2px 8px #a5f88a33;
}

::-webkit-scrollbar-thumb {
    background: #b7e7f8;
    border-radius: 7px;
}
::-webkit-scrollbar-track {
    background: #e8f7ff;
}

/* Easter egg: style the GWAY QR as an XP desktop icon if possible */
aside img[src*="qr"] {
    border-radius: 14px;
    border: 2px solid #5ad5fe;
    box-shadow: 2px 4px 18px #74e2fa44;
    padding: 5px;
    background: #f5fff8;
}
